is_supported_variable: Check if a Variable is Supported

View source: R/0_s3_methods.R

is_supported_variableR Documentation

Check if a Variable is Supported

Description

This function is a generic method that checks if a given variable is supported. The actual implementation of the check is provided by specific methods for different classes of variables.

Usage

is_supported_variable(x)

Arguments

x

The variable to be checked.

Value

A logical value indicating whether the variable is supported.


recforest documentation built on Jan. 13, 2026, 5:07 p.m.