make_decision: Make a Decision Based on Input

View source: R/0_s3_methods.R

make_decisionR Documentation

Make a Decision Based on Input

Description

This function serves as a generic method for making decisions based on the input x and value. It dispatches to the appropriate method depending on the class of x.

Usage

make_decision(x, value)

Arguments

x

An object for which a decision needs to be made.

value

A value that influences the decision-making process.

Value

The result of the decision-making process, which depends on the specific method implementation.


recforest documentation built on Jan. 13, 2026, 5:07 p.m.